@@ -6,23 +6,23 @@ use Example::Syntax;
 
 extends 'Example::Controller';
 
-sub root :Via('../protected') At('account/...') ($self, $c, $user) {
+sub root :At('$path_end/...') Via('../protected')  ($self, $c, $user) {
   $c->action->next($user->account);
 }
 
-  sub prepare_edit :Via('root') At('...') ($self, $c, $account) { 
+  sub prepare_edit :At('...') Via('root') ($self, $c, $account) { 
     $self->view_for('edit', account => $account);
     $c->action->next($account);
   }
 
-    sub edit :GET Via('prepare_edit') At('edit') ($self, $c, $account) {
+    sub edit :Get('edit') Via('prepare_edit') ($self, $c, $account) {
       return  $c->view->set_http_ok;
     }
 
-    sub update :PATCH Via('prepare_edit') At('') BodyModel ($self, $c, $account, $r) {
-      return $account->update_account($r) ?
+    sub update :Patch('') Via('prepare_edit') BodyModel ($self, $c, $account, $bm) {
+      return $account->update_account($bm) ?
         $c->view->set_http_ok : 
           $c->view->set_http_bad_request;
     }
 
-__PACKAGE__->meta->make_immutable;
\ No newline at end of file
+__PACKAGE__->meta->make_immutable;
